@@ -1,4 +1,5 @@
 use {
+    super::detect_support::is_kitty_graphics_protocol_supported,
     crate::{
         display::{
             cell_size_in_pixels,
@@ -19,19 +20,17 @@ use {
         RgbaImage,
     },
     std::{
-        env,
         io::{self, Write},
     },
     tempfile,
     termimad::Area,
 };
 
-pub type KittyImageSet = Vec<usize>;
-
 /// How to send the image to kitty
 ///
 /// Note that I didn't test yet the named shared memory
 /// solution offered by kitty.
+#[derive(Debug)]
 pub enum TransmissionMedium {
     /// write a temp file, then give its path to kitty
     /// in the payload of the escape sequence. It's quite
@@ -84,41 +83,22 @@ impl<'i> ImageData<'i> {
 /// according to kitty's documentation
 const CHUNK_SIZE: usize = 4096;
 
-/// until I'm told there's another terminal supporting the kitty
-/// terminal, I think I can just check the name
-pub fn is_term_kitty() -> bool {
-    if let Ok(term_name) = env::var("TERM") {
-        debug!("TERM env var: {:?}", env::var("TERM"));
-        if term_name.contains("kitty") {
-            return true;
-        }
-    }
-    if let Ok(term_name) = env::var("TERMINAL") {
-        debug!("TERMINAL env var: {:?}", env::var("TERMINAL"));
-        if term_name.contains("kitty") {
-            return true;
-        }
-    }
-    false
-}
 
 fn div_ceil(a: u32, b: u32) -> u32 {
     a / b + (0 != a % b) as u32
 }
 
-/// the image renderer, with knowledge of the
-/// console cells dimensions, and built only on Kitty.
-///
+/// The image renderer, with knowledge of the console cells
+/// dimensions, and built only on a compatible terminal
+#[derive(Debug)]
 pub struct KittyImageRenderer {
     cell_width: u32,
     cell_height: u32,
     next_id: usize,
-    current_images: Option<KittyImageSet>,
     pub transmission_medium: TransmissionMedium,
 }
 
 /// An image prepared for a precise area on screen
-///
 struct KittyImage<'i> {
     id: usize,
     data: ImageData<'i>,
@@ -144,7 +124,7 @@ impl<'i> KittyImage<'i> {
             area,
         }
     }
-    /// render the image by sending multiple kitty escape sequence, each
+    /// Render the image by sending multiple kitty escape sequences, each
     /// one with part of the image raw data (encoded as base64)
     fn print_with_chunks(
         &self,
@@ -175,7 +155,7 @@ impl<'i> KittyImage<'i> {
         }
         Ok(())
     }
-    /// render the image by writing the raw data in a temporary file
+    /// Render the image by writing the raw data in a temporary file
     /// then giving to kitty the path to this file in the payload of
     /// a unique kitty ecape sequence
     pub fn print_with_temp_file(
@@ -217,8 +197,9 @@ impl<'i> KittyImage<'i> {
 }
 
 impl KittyImageRenderer {
+    /// Called only once (at most) by the KittyManager
     pub fn new() -> Option<Self> {
-        if !is_term_kitty() {
+        if !is_kitty_graphics_protocol_supported() {
             return None;
         }
         cell_size_in_pixels()
@@ -226,54 +207,31 @@ impl KittyImageRenderer {
             .map(|(cell_width, cell_height)| Self {
                 cell_width,
                 cell_height,
-                current_images: None,
                 next_id: 1,
                 transmission_medium: TransmissionMedium::Chunks,
             })
     }
-    pub fn take_current_images(&mut self) -> Option<KittyImageSet> {
-        self.current_images.take()
-    }
-    /// return a new image id which is assumed will be used
+    /// return a new image id
     fn new_id(&mut self) -> usize {
         let new_id = self.next_id;
         self.next_id += 1;
-        self.current_images
-            .get_or_insert_with(Vec::new)
-            .push(new_id);
         new_id
     }
+    /// Print the dynamicImage and return the KittyImageId
+    /// for later removal from screen
     pub fn print(
         &mut self,
         w: &mut W,
         src: &DynamicImage,
         area: &Area,
-    ) -> Result<(), ProgramError> {
+    ) -> Result<usize, ProgramError> {
         let img = KittyImage::new(src, area, self);
+        debug!("transmission medium: {:?}", self.transmission_medium);
         match self.transmission_medium {
-            TransmissionMedium::TempFile => img.print_with_temp_file(w),
-            TransmissionMedium::Chunks => img.print_with_chunks(w),
+            TransmissionMedium::TempFile => img.print_with_temp_file(w)?,
+            TransmissionMedium::Chunks => img.print_with_chunks(w)?,
         }
-    }
-    pub fn erase(
-        &mut self,
-        w: &mut W,
-        ids: KittyImageSet,
-    ) -> Result<(), ProgramError> {
-        for id in ids {
-            debug!("erase kitty image {}", id);
-            write!(w, "\u{1b}_Ga=d,d=I,i={}\u{1b}\\", id)?;
-        }
-        Ok(())
-    }
-    /// erase all kitty images, even the forgetted ones
-    pub fn erase_all(
-        &mut self,
-        w: &mut W,
-    ) -> Result<(), ProgramError> {
-        write!(w, "\u{1b}_Ga=d,d=A\u{1b}\\")?;
-        self.current_images = None;
-        Ok(())
+        Ok(img.id)
     }
     fn rendering_area(
         &self,
