@@ -87,8 +87,16 @@ impl<'c> TreeBuilder<'c> {
             None
         };
         let root_id = BLine::from_root(&mut blines, path, root_ignore_chain, &options)?;
-        let trim_root = options.pattern.is_some()
-            || (options.trim_root && !options.sort.is_some());
+        let trim_root = match (options.trim_root, options.pattern.is_some(), options.sort.is_some()) {
+            // we never want to trim the root if there's a sort
+            (_, _, true) => false,
+            // if the user don't want root trimming, we don't trim
+            (false, _, _) => false,
+            // if there's a pattern, we try to show at least root matches
+            (_, true, _) => false,
+            // in other cases, as the user wants trimming, we trim
+            _ => true,
+        };
         Ok(TreeBuilder {
             options,
             targeted_size,
@@ -439,7 +447,10 @@ impl<'c> TreeBuilder<'c> {
     pub fn build(mut self, total_search: bool, dam: &Dam) -> Option<Tree> {
         match self.gather_lines(total_search, dam) {
             Some(out_blines) => {
-                self.trim_excess(&out_blines);
+                debug!("blines before trimming: {}", out_blines.len());
+                if !self.total_search {
+                    self.trim_excess(&out_blines);
+                }
                 Some(self.take(&out_blines))
             }
             None => None, // interrupted
